@@ -16,7 +16,7 @@ require Exporter;
  crc32_hex crc32_base64
 );
 
-$VERSION    = '0.10';
+$VERSION    = '0.14';
 $XS_VERSION = $VERSION;
 $VERSION    = eval $VERSION;
 
@@ -76,7 +76,8 @@ sub _tabinit {
 	}
       }
     }
-    push @crctab, $r&2**$width-1;
+    my $x=$r&2**$width-1;
+    push @crctab, $x;
   }
   \@crctab;
 }
@@ -84,7 +85,7 @@ sub _tabinit {
 sub _crc {
   my ($message,$width,$init,$xorout,$refin,$refout,$tab) = @_;
   my $crc = $init;
-  $crc = __reflect($crc,$width) if $refin;
+  $crc = _reflect($crc,$width) if $refin;
   my $pos = -length $message;
   my $mask = 2**$width-1;
   while ($pos) {
@@ -96,7 +97,6 @@ sub _crc {
   }
 
   if ($refout^$refin) {
-    print STDERR "refout\n";
     $crc = _reflect($crc,$width);
   }
 
